@@ -86,7 +86,7 @@
 #define KBOOKMARKS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KBOOKMARKS_NO_DEPRECATED
-#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KBOOKMARKS_NO_DEPRECATED_WARNINGS
 #  define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -130,5 +130,12 @@
 #define KBOOKMARKS_DEPRECATED_VERSION_5(minor, text)      KBOOKMARKS_DEPRECATED_VERSION_5_##minor(text)
 #define KBOOKMARKS_DEPRECATED_VERSION(major, minor, text) KBOOKMARKS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KBOOKMARKS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KBOOKMARKS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KBOOKMARKS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KBOOKMARKS_DEPRECATED_VERSION(major, minor, text)
+#  define KBOOKMARKS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KBOOKMARKS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KBOOKMARKS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KBOOKMARKS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KBOOKMARKS_EXPORT_H */
